# SJTU Schedule Exporter CLI

A simple utility to export your SJTU schedule in ICS format.

## Get Started

``` shell script
$ pip install sjtu-schedule-exporter-cli
$ sjtu-schedule-exporter-cli
```

## Screenshot

![screenshot](https://raw.githubusercontent.com/PhotonQuantum/sjtu-schedule-exporter-cli/master/screenshot.png)

## Built With

- [PySJTU](https://github.com/PhotonQuantum/pysjtu) - The Python iSJTU client for Humans. 
- [ics.py](https://github.com/C4ptainCrunch/ics.py) - A pythonic and easy iCalendar library.
- [Blessed](https://github.com/jquast/blessed) - An easy, practical library for making terminal apps.
- [Arrow](https://github.com/arrow-py/arrow) - Better dates & times for Python

## License

This project is licensed under GNU General Public License v3.0 - see the [LICENSE.md](https://github.com/PhotonQuantum/sjtu-schedule-exporter-cli/blob/master/LICENSE.md) file for details.

<p align="center">&mdash;💖&mdash;</p>
<p align="center"><i>Built with love by LightQuantum</i></p>
